<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8" />
    <meta
      http-equiv="Content-Security-Policy"
      content="script-src 'self' 'unsafe-inline'"
    />
    <title>Claude Excel Agent</title>
  </head>
  <body>
    <div id="root"></div>
  </body>
</html>
